==> tfx-cli-0.1.5.tgz: package/exec/login.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var cmdm = require('../lib/tfcommand');
var Q = require('q');
var csm = require('../lib/credstore');
var cam = require('../lib/diskcache');
var params = require('../lib/parameternames');
var trace = require('../lib/trace');
function describe() {
    return 'login and cache credentials. types: pat (default), basic';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([params.COLLECTION_URL], [params.AUTH_TYPE]);
}
exports.getArguments = getArguments;
function getCommand() {
    // this just offers description for help and to offer sub commands
    return new Login();
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = true;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var Login = (function (_super) {
    __extends(Login, _super);
    function Login() {
        _super.apply(this, arguments);
    }
    Login.prototype.exec = function (args, options) {
        var _this = this;
        trace('Login.exec');
        var defer = Q.defer();
        // TODO: validate valid url
        var con = this.connection;
        var cache = new cam.DiskCache('tfx');
        var cs = csm.getCredentialStore('tfx');
        trace('Caching credentials...');
        cs.storeCredential(con.collectionUrl, 'allusers', con.credentials.toString()).then(function () {
            return cache.setItem('cache', 'connection', con.collectionUrl);
        }).then(function () {
            trace('Connecting to agent API to test credentials...');
            var agentapi = _this.getWebApi().getTaskAgentApi();
            agentapi.connect(function (err, statusCode, obj) {
                if (statusCode && statusCode == 401) {
                    trace('Connection failed. Invalid credentials');
                    defer.reject(new Error('Invalid credentials'));
                }
                defer.resolve(con.credentials);
            });
        }).fail(function (err) {
            trace('Login Failed: ' + err.message);
            defer.reject('Login Failed: ' + err.message);
        });
        return defer.promise;
    };
    Login.prototype.output = function (creds) {
        console.log('logged in successfully');
    };
    return Login;
})(cmdm.TfCommand);
exports.Login = Login;

==> tfx-cli-0.1.8.tgz: package/exec/login.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var cmdm = require('../lib/tfcommand');
var Q = require('q');
var csm = require('../lib/credstore');
var cam = require('../lib/diskcache');
var params = require('../lib/parameternames');
var trace = require('../lib/trace');
function describe() {
    return 'login and cache credentials. types: pat (default), basic';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([params.COLLECTION_URL], [params.AUTH_TYPE]);
}
exports.getArguments = getArguments;
function getCommand() {
    // this just offers description for help and to offer sub commands
    return new Login();
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = true;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var Login = (function (_super) {
    __extends(Login, _super);
    function Login() {
        _super.apply(this, arguments);
    }
    Login.prototype.exec = function (args, options) {
        var _this = this;
        trace('Login.exec');
        var defer = Q.defer();
        // TODO: validate valid url
        var con = this.connection;
        var cache = new cam.DiskCache('tfx');
        var cs = csm.getCredentialStore('tfx');
        trace('Caching credentials...');
        cs.storeCredential(con.collectionUrl, 'allusers', con.credentials.toString())
            .then(function () {
            return cache.setItem('cache', 'connection', con.collectionUrl);
        })
            .then(function () {
            trace('Connecting to agent API to test credentials...');
            var agentapi = _this.getWebApi().getTaskAgentApi();
            agentapi.connect(function (err, statusCode, obj) {
                if (statusCode && statusCode == 401) {
                    trace('Connection failed. Invalid credentials');
                    defer.reject(new Error('Invalid credentials'));
                }
                defer.resolve(con.credentials);
            });
        })
            .fail(function (err) {
            trace('Login Failed: ' + err.message);
            defer.reject('Login Failed: ' + err.message);
        });
        return defer.promise;
    };
    Login.prototype.output = function (creds) {
        console.log('logged in successfully');
    };
    return Login;
})(cmdm.TfCommand);
exports.Login = Login;
